BrowserInstallationCache (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers
Class BrowserInstallationCache

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.BrowserInstallationCache

    public class BrowserInstallationCache

extends java.lang.Object

Cache browser installation corresponding to a spefic browser string and launcher location.

Constructor Summary
`BrowserInstallationCache()`

Method Summary
`protected java.lang.String` | `cacheKey(java.lang.String browserString, java.lang.String customLauncherPath)`
`BrowserInstallation` | `locateBrowserInstallation(java.lang.String browserName, java.lang.String customLauncherPath, BrowserLocator locator)`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### BrowserInstallationCache

    public BrowserInstallationCache()

Method Detail

### locateBrowserInstallation

    public BrowserInstallation locateBrowserInstallation(java.lang.String browserName,
                                                         java.lang.String customLauncherPath,
                                                         BrowserLocator locator)

### cacheKey

    protected java.lang.String cacheKey(java.lang.String browserString,
                                        java.lang.String customLauncherPath)

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.